@@ -725,14 +725,15 @@ class CfnFileSystem(
         jsii_type="@aws-cdk/aws-fsx.CfnFileSystem.WindowsConfigurationProperty",
         jsii_struct_bases=[],
         name_mapping={
+            "throughput_capacity": "throughputCapacity",
             "active_directory_id": "activeDirectoryId",
+            "aliases": "aliases",
             "automatic_backup_retention_days": "automaticBackupRetentionDays",
             "copy_tags_to_backups": "copyTagsToBackups",
             "daily_automatic_backup_start_time": "dailyAutomaticBackupStartTime",
             "deployment_type": "deploymentType",
             "preferred_subnet_id": "preferredSubnetId",
             "self_managed_active_directory_configuration": "selfManagedActiveDirectoryConfiguration",
-            "throughput_capacity": "throughputCapacity",
             "weekly_maintenance_start_time": "weeklyMaintenanceStartTime",
         },
     )
@@ -740,32 +741,38 @@ class CfnFileSystem(
         def __init__(
             self,
             *,
+            throughput_capacity: jsii.Number,
             active_directory_id: typing.Optional[builtins.str] = None,
+            aliases: typing.Optional[typing.List[builtins.str]] = None,
             automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
             copy_tags_to_backups: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
             daily_automatic_backup_start_time: typing.Optional[builtins.str] = None,
             deployment_type: typing.Optional[builtins.str] = None,
             preferred_subnet_id: typing.Optional[builtins.str] = None,
             self_managed_active_directory_configuration: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty"]] = None,
-            throughput_capacity: typing.Optional[jsii.Number] = None,
             weekly_maintenance_start_time: typing.Optional[builtins.str] = None,
         ) -> None:
             '''
+            :param throughput_capacity: ``CfnFileSystem.WindowsConfigurationProperty.ThroughputCapacity``.
             :param active_directory_id: ``CfnFileSystem.WindowsConfigurationProperty.ActiveDirectoryId``.
+            :param aliases: ``CfnFileSystem.WindowsConfigurationProperty.Aliases``.
             :param automatic_backup_retention_days: ``CfnFileSystem.WindowsConfigurationProperty.AutomaticBackupRetentionDays``.
             :param copy_tags_to_backups: ``CfnFileSystem.WindowsConfigurationProperty.CopyTagsToBackups``.
             :param daily_automatic_backup_start_time: ``CfnFileSystem.WindowsConfigurationProperty.DailyAutomaticBackupStartTime``.
             :param deployment_type: ``CfnFileSystem.WindowsConfigurationProperty.DeploymentType``.
             :param preferred_subnet_id: ``CfnFileSystem.WindowsConfigurationProperty.PreferredSubnetId``.
             :param self_managed_active_directory_configuration: ``CfnFileSystem.WindowsConfigurationProperty.SelfManagedActiveDirectoryConfiguration``.
-            :param throughput_capacity: ``CfnFileSystem.WindowsConfigurationProperty.ThroughputCapacity``.
             :param weekly_maintenance_start_time: ``CfnFileSystem.WindowsConfigurationProperty.WeeklyMaintenanceStartTime``.
 
             :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-windowsconfiguration.html
             '''
-            self._values: typing.Dict[str, typing.Any] = {}
+            self._values: typing.Dict[str, typing.Any] = {
+                "throughput_capacity": throughput_capacity,
+            }
             if active_directory_id is not None:
                 self._values["active_directory_id"] = active_directory_id
+            if aliases is not None:
+                self._values["aliases"] = aliases
             if automatic_backup_retention_days is not None:
                 self._values["automatic_backup_retention_days"] = automatic_backup_retention_days
             if copy_tags_to_backups is not None:
@@ -778,11 +785,19 @@ class CfnFileSystem(
                 self._values["preferred_subnet_id"] = preferred_subnet_id
             if self_managed_active_directory_configuration is not None:
                 self._values["self_managed_active_directory_configuration"] = self_managed_active_directory_configuration
-            if throughput_capacity is not None:
-                self._values["throughput_capacity"] = throughput_capacity
             if weekly_maintenance_start_time is not None:
                 self._values["weekly_maintenance_start_time"] = weekly_maintenance_start_time
 
+        @builtins.property
+        def throughput_capacity(self) -> jsii.Number:
+            '''``CfnFileSystem.WindowsConfigurationProperty.ThroughputCapacity``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-windowsconfiguration.html#cfn-fsx-filesystem-windowsconfiguration-throughputcapacity
+            '''
+            result = self._values.get("throughput_capacity")
+            assert result is not None, "Required property 'throughput_capacity' is missing"
+            return typing.cast(jsii.Number, result)
+
         @builtins.property
         def active_directory_id(self) -> typing.Optional[builtins.str]:
             '''``CfnFileSystem.WindowsConfigurationProperty.ActiveDirectoryId``.
@@ -792,6 +807,15 @@ class CfnFileSystem(
             result = self._values.get("active_directory_id")
             return typing.cast(typing.Optional[builtins.str], result)
 
+        @builtins.property
+        def aliases(self) -> typing.Optional[typing.List[builtins.str]]:
+            '''``CfnFileSystem.WindowsConfigurationProperty.Aliases``.
+
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-windowsconfiguration.html#cfn-fsx-filesystem-windowsconfiguration-aliases
+            '''
+            result = self._values.get("aliases")
+            return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+
         @builtins.property
         def automatic_backup_retention_days(self) -> typing.Optional[jsii.Number]:
             '''``CfnFileSystem.WindowsConfigurationProperty.AutomaticBackupRetentionDays``.
@@ -850,15 +874,6 @@ class CfnFileSystem(
             result = self._values.get("self_managed_active_directory_configuration")
             return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnFileSystem.SelfManagedActiveDirectoryConfigurationProperty"]], result)
 
-        @builtins.property
-        def throughput_capacity(self) -> typing.Optional[jsii.Number]:
-            '''``CfnFileSystem.WindowsConfigurationProperty.ThroughputCapacity``.
-
-            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fsx-filesystem-windowsconfiguration.html#cfn-fsx-filesystem-windowsconfiguration-throughputcapacity
-            '''
-            result = self._values.get("throughput_capacity")
-            return typing.cast(typing.Optional[jsii.Number], result)
-
         @builtins.property
         def weekly_maintenance_start_time(self) -> typing.Optional[builtins.str]:
             '''``CfnFileSystem.WindowsConfigurationProperty.WeeklyMaintenanceStartTime``.
